==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebValuesChangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebValuesChangeDescription } from "./WebValuesChangeDescription";
/**
 * @hidden
 */
var WebValuesChangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebValuesChangeDescriptionMetadata, _super);
    function WebValuesChangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebValuesChangeDescriptionMetadata.b = function (a) {
        if (WebValuesChangeDescriptionMetadata.a == null) {
            WebValuesChangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebValuesChangeDescriptionMetadata.c(WebValuesChangeDescriptionMetadata.a);
        }
        if (a.j(WebValuesChangeDescriptionMetadata.a)) {
            return;
        }
        a.y(WebValuesChangeDescriptionMetadata.a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebValuesChangeDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ValuesChange");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Values", "Array:WebPivotValueDescription:PivotValue");
    };
    WebValuesChangeDescriptionMetadata.d = function (a) {
        WebValuesChangeDescriptionMetadata.b(a);
        a.aa("WebValuesChange", function () { return new WebValuesChangeDescription(); });
        a.z("WebValuesChange", WebValuesChangeDescriptionMetadata.a);
    };
    WebValuesChangeDescriptionMetadata.$t = markType(WebValuesChangeDescriptionMetadata, 'WebValuesChangeDescriptionMetadata');
    WebValuesChangeDescriptionMetadata.a = null;
    return WebValuesChangeDescriptionMetadata;
}(Base));
export { WebValuesChangeDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebValuesChangeDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebValuesChangeDescription } from "./WebValuesChangeDescription";
/**
 * @hidden
 */
var WebValuesChangeDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebValuesChangeDescriptionMetadata, _super);
    function WebValuesChangeDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebValuesChangeDescriptionMetadata.b = function (a) {
        if (WebValuesChangeDescriptionMetadata.a == null) {
            WebValuesChangeDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebValuesChangeDescriptionMetadata.c(WebValuesChangeDescriptionMetadata.a);
        }
        if (a.k(WebValuesChangeDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebValuesChangeDescriptionMetadata.a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebValuesChangeDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ValuesChange");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Values", "Array:WebPivotValueDescription:PivotValue");
    };
    WebValuesChangeDescriptionMetadata.d = function (a) {
        WebValuesChangeDescriptionMetadata.b(a);
        a.ac("WebValuesChange", function () { return new WebValuesChangeDescription(); });
        a.ab("WebValuesChange", WebValuesChangeDescriptionMetadata.a);
    };
    WebValuesChangeDescriptionMetadata.$t = markType(WebValuesChangeDescriptionMetadata, 'WebValuesChangeDescriptionMetadata');
    WebValuesChangeDescriptionMetadata.a = null;
    return WebValuesChangeDescriptionMetadata;
}(Base));
export { WebValuesChangeDescriptionMetadata };
